==> office-ui-fabric-vue-7.0.26.tgz: package/lib/components/DetailsList/DetailsRow/DetailsRowFields.js <==
import '../../node_modules/core-js/modules/es.date.to-string.js';
import '../../node_modules/core-js/modules/es.object.to-string.js';
import '../../node_modules/core-js/modules/es.reflect.construct.js';
import '../../node_modules/core-js/modules/es.regexp.to-string.js';
import _classCallCheck from '@babel/runtime/helpers/classCallCheck';
import _createClass from '@babel/runtime/helpers/createClass';
import _inherits from '@babel/runtime/helpers/inherits';
import _possibleConstructorReturn from '@babel/runtime/helpers/possibleConstructorReturn';
import _getPrototypeOf from '@babel/runtime/helpers/getPrototypeOf';
import { __decorate, __metadata } from 'tslib';
import { Prop, Component } from 'vue-property-decorator';
import { css } from '@uifabric-vue/utilities';
import BaseComponent from '../../BaseComponent.js';
import '../../node_modules/core-js/modules/es.array.map.js';
import '../../node_modules/core-js/modules/es.number.constructor.js';
import { DEFAULT_CELL_STYLE_PROPS } from './DetailsRow.styles.js';

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Date.prototype.toString.call(Reflect.construct(Date, [], function () {})); return true; } catch (e) { return false; } }

var getCellText = function getCellText(item, column) {
  var value = item && column && column.fieldName ? item[column.fieldName] : '';

  if (value === null || value === undefined) {
    value = '';
  }

  if (typeof value === 'boolean') {
    return value.toString();
  }

  return value;
};

var DetailsRowFields = function (_BaseComponent) {
  _inherits(DetailsRowFields, _BaseComponent);

  var _super = _createSuper(DetailsRowFields);

  function DetailsRowFields() {
    var _this;

    _classCallCheck(this, DetailsRowFields);

    _this = _super.apply(this, arguments);
    _this.showAnimation = true;
    return _this;
  }

  _createClass(DetailsRowFields, [{
    key: "calcWidth",
    value: function calcWidth(column) {
      var cellStyleProps = this.cellStyleProps;
      var width = typeof column.calculatedWidth === 'undefined' ? 'auto' : column.calculatedWidth + cellStyleProps.cellLeftPadding + cellStyleProps.cellRightPadding + (column.isPadded ? cellStyleProps.cellExtraRightPadding : 0) + 'px';
      return width;
    }
  }, {
    key: "render",
    value: function render() {
      var _this2 = this;

      var h = arguments[0];
      var rowClassNames = this.rowClassNames,
          columns = this.columns,
          showAnimation = this.showAnimation,
          item = this.item;
      return h("div", {
        "class": rowClassNames.fields,
        "attrs": {
          "role": "presentation"
        }
      }, [columns.map(function (column, columnIndex) {
        var slot = _this2.$scopedSlots["cell.".concat(column.key)];

        return h("div", {
          "key": columnIndex,
          "attrs": {
            "role": column.isRowHeader ? 'rowheader' : 'gridcell',
            "aria-readonly": true
          },
          "style": {
            width: _this2.calcWidth(column)
          },
          "class": css(column.className, column.isMultiline && rowClassNames.isMultiline, column.isRowHeader && rowClassNames.isRowHeader, rowClassNames.cell, column.isPadded ? rowClassNames.cellPadded : rowClassNames.cellUnpadded, showAnimation && rowClassNames.cellAnimation)
        }, [slot ? slot({
          item: item,
          column: column
        }) : getCellText(item, column)]);
      })]);
    }
  }]);

  return DetailsRowFields;
}(BaseComponent);

__decorate([Prop({
  type: Object,
  required: true
}), __metadata("design:type", Object)], DetailsRowFields.prototype, "rowClassNames", void 0);

__decorate([Prop({
  type: Array,
  required: true
}), __metadata("design:type", Array)], DetailsRowFields.prototype, "columns", void 0);

__decorate([Prop({
  type: Object,
  required: true
}), __metadata("design:type", Object)], DetailsRowFields.prototype, "item", void 0);

__decorate([Prop({
  type: Number,
  required: true
}), __metadata("design:type", Number)], DetailsRowFields.prototype, "itemIndex", void 0);

__decorate([Prop({
  type: Object,
  "default": function _default() {
    return DEFAULT_CELL_STYLE_PROPS;
  }
}), __metadata("design:type", Object)], DetailsRowFields.prototype, "cellStyleProps", void 0);

DetailsRowFields = __decorate([Component], DetailsRowFields);

export { DetailsRowFields };

==> office-ui-fabric-vue-7.0.27.tgz: package/lib/components/DetailsList/DetailsRow/DetailsRowFields.js <==
import 'core-js/modules/es.object.to-string';
import 'core-js/modules/es.reflect.construct';
import 'core-js/modules/es.regexp.to-string';
import _classCallCheck from '@babel/runtime/helpers/classCallCheck';
import _createClass from '@babel/runtime/helpers/createClass';
import _inherits from '@babel/runtime/helpers/inherits';
import _possibleConstructorReturn from '@babel/runtime/helpers/possibleConstructorReturn';
import _getPrototypeOf from '@babel/runtime/helpers/getPrototypeOf';
import { __decorate, __metadata } from 'tslib';
import { Prop, Component } from 'vue-property-decorator';
import { css } from '@uifabric-vue/utilities';
import BaseComponent from '../../BaseComponent.js';
import 'core-js/modules/es.array.map';
import 'core-js/modules/es.number.constructor';
import { DEFAULT_CELL_STYLE_PROPS } from './DetailsRow.styles.js';

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Date.prototype.toString.call(Reflect.construct(Date, [], function () {})); return true; } catch (e) { return false; } }

var getCellText = function getCellText(item, column) {
  var value = item && column && column.fieldName ? item[column.fieldName] : '';

  if (value === null || value === undefined) {
    value = '';
  }

  if (typeof value === 'boolean') {
    return value.toString();
  }

  return value;
};

var DetailsRowFields = function (_BaseComponent) {
  _inherits(DetailsRowFields, _BaseComponent);

  var _super = _createSuper(DetailsRowFields);

  function DetailsRowFields() {
    var _this;

    _classCallCheck(this, DetailsRowFields);

    _this = _super.apply(this, arguments);
    _this.showAnimation = true;
    return _this;
  }

  _createClass(DetailsRowFields, [{
    key: "calcWidth",
    value: function calcWidth(column) {
      var cellStyleProps = this.cellStyleProps;
      var width = typeof column.calculatedWidth === 'undefined' ? 'auto' : column.calculatedWidth + cellStyleProps.cellLeftPadding + cellStyleProps.cellRightPadding + (column.isPadded ? cellStyleProps.cellExtraRightPadding : 0) + 'px';
      return width;
    }
  }, {
    key: "render",
    value: function render() {
      var _this2 = this;

      var h = arguments[0];
      var rowClassNames = this.rowClassNames,
          columns = this.columns,
          showAnimation = this.showAnimation,
          item = this.item;
      return h("div", {
        "class": rowClassNames.fields,
        "attrs": {
          "role": "presentation"
        }
      }, [columns.map(function (column, columnIndex) {
        var slot = _this2.$scopedSlots["cell.".concat(column.key)];

        return h("div", {
          "key": columnIndex,
          "attrs": {
            "role": column.isRowHeader ? 'rowheader' : 'gridcell',
            "aria-readonly": true
          },
          "style": {
            width: _this2.calcWidth(column)
          },
          "class": css(column.className, column.isMultiline && rowClassNames.isMultiline, column.isRowHeader && rowClassNames.isRowHeader, rowClassNames.cell, column.isPadded ? rowClassNames.cellPadded : rowClassNames.cellUnpadded, showAnimation && rowClassNames.cellAnimation)
        }, [slot ? slot({
          item: item,
          column: column
        }) : getCellText(item, column)]);
      })]);
    }
  }]);

  return DetailsRowFields;
}(BaseComponent);

__decorate([Prop({
  type: Object,
  required: true
}), __metadata("design:type", Object)], DetailsRowFields.prototype, "rowClassNames", void 0);

__decorate([Prop({
  type: Array,
  required: true
}), __metadata("design:type", Array)], DetailsRowFields.prototype, "columns", void 0);

__decorate([Prop({
  type: Object,
  required: true
}), __metadata("design:type", Object)], DetailsRowFields.prototype, "item", void 0);

__decorate([Prop({
  type: Number,
  required: true
}), __metadata("design:type", Number)], DetailsRowFields.prototype, "itemIndex", void 0);

__decorate([Prop({
  type: Object,
  default: function _default() {
    return DEFAULT_CELL_STYLE_PROPS;
  }
}), __metadata("design:type", Object)], DetailsRowFields.prototype, "cellStyleProps", void 0);

DetailsRowFields = __decorate([Component], DetailsRowFields);

export { DetailsRowFields };
